#[macro_use]
extern crate clap;
extern crate ldap3;

mod ldap;

use clap::{App, Arg, SubCommand};

fn main() {
  // parse options
  let matches = App::new("Metaunix.net LDAP tool")
    .version("0.1.0")
    .author("Gregory W. Ballantine <gballantine555@gmail.com>")
    .about("Tool to manage LDAP resources for Metaunix.net")

    // LDAP search subcommand
    .subcommand(SubCommand::with_name("search")
      .about("Search an LDAP directory")
      .arg(Arg::with_name("server")
        .short("s")
        .long("server")
        .takes_value(true)
        .help("LDAP server to search"))
      .arg(Arg::with_name("port")
        .short("p")
        .long("port")
        .takes_value(true)
        .help("Port on which the LDAP server is listening on"))
      .arg(Arg::with_name("base")
        .short("b")
        .long("base")
        .takes_value(true)
        .help("Base DN to search with")))

    .get_matches();

  // check for subcommand
  if let Some(matches) = matches.subcommand_matches("search") {
    let server = matches.value_of("server").unwrap();
    let port = value_t!(matches, "port", u16).unwrap_or(389);
    let base = matches.value_of("base").unwrap();
    let _ = ldap::do_search(server, port, base);
  }
}
